from django.forms import ModelChoiceField, ModelMultipleChoiceField


class SafeModelChoiceField(ModelChoiceField):
    def __init__(self, queryset, **kwargs):
        queryset = queryset.model.objects.none()
        super().__init__(queryset, **kwargs)


class SafeModelMultipleChoiceField(ModelMultipleChoiceField):
    def __init__(self, queryset, **kwargs):
        queryset = queryset.model.objects.none()
        super().__init__(queryset, **kwargs)



from contextlib import contextmanager
from threading import local

state = local()


@contextmanager
def scopes_disabled():
    with scope(_enabled=False):
        yield


@contextmanager
def scope(**scope_kwargs):
    if not hasattr(state, 'scope'):
        state.scope = {}

    previous_scope = getattr(state, 'scope', {})
    new_scope = dict(previous_scope)
    new_scope['_enabled'] = True
    new_scope.update(scope_kwargs)
    state.scope = new_scope
    try:
        yield
    finally:
        state.scope = previous_scope


def get_scope():
    return dict(getattr(state, 'scope', {}))



from codecs import open
from os import path

from setuptools import find_packages, setup

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
try:
    with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
        long_description = f.read()
except:
    long_description = ''

try:
    from django_scopes import version
except ImportError:
    version = '?'

setup(
    name='django-scopes',
    version=version,
    description='Scope querys in multi-tenant django applications',
    long_description=long_description,
    url='https://github.com/raphaelm/django-scopes',
    author='Raphael Michel',
    author_email='mail@raphaelmichel.de',
    license='Apache License 2.0',
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Other Audience',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Framework :: Django :: 2.1',
        'Framework :: Django :: 2.2',
    ],

    keywords='json database models',
    install_requires=[
    ],

    packages=find_packages(exclude=['tests', 'tests.*', 'demoproject', 'demoproject.*']),
    include_package_data=True,
)
